@@ -1,4 +1,4 @@
-# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2023, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/particle for details.
@@ -206,7 +206,7 @@ class Particle:
     latex_name: str = attr.ib("Unknown")
 
     def __repr__(self) -> str:
-        return f'<{self.__class__.__name__}: name="{self}", pdgid={int(self.pdgid)}, mass={self._str_mass()}>'
+        return f'<{self.__class__.__name__}: name="{self}", pdgid={int(self.pdgid)}, mass={self._str_mass()}>'  # noqa: B907
 
     # Ordered loaded table of entries
     _table: list[Particle] | None = None
@@ -991,7 +991,7 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
         Raises
         ------
         ParticleNotFound
-            If no particle matches the input name.
+            If no particle matches the input name uniquely and exactly.
         """
         try:
             (particle,) = cls.finditer(
@@ -999,7 +999,7 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
             )  # throws an error if < 1 or > 1 particle is found
             return particle
         except ValueError:
-            raise ParticleNotFound(f'Could not find name "{name}"') from None
+            raise ParticleNotFound(f"Could not find name {name!r}") from None
 
     @classmethod
     def from_evtgen_name(cls: type[Self], name: str) -> Self:
@@ -1238,12 +1238,6 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
             cls.finditer(filter_fn=filter_fn, particle=particle, **search_terms)
         )
 
-    @classmethod
-    def find(cls: type[Self], *args: Any, **search_terms: Any) -> Self:
-        raise AttributeError(
-            "Method has been removed post versions 0.16. Please use finditer or findall instead."
-        )
-
     @classmethod
     def from_string(cls: type[Self], name: str) -> Self:
         "Get a particle from a PDG style name - returns the best match."
