@@ -1,4 +1,4 @@
-# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2023, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/particle for details.
@@ -147,25 +147,57 @@ def test_pdg_convert():
     assert int(p.pdgid) == 211
 
 
-def test_nucleus_convert():
+def test_from_name():
+    p = Particle.from_name("pi+")
+    assert p.name == "pi+"
+
+
+def test_from_name_ParticleNotFound():
+    """
+    Exception raised because the name given matches all pions,
+    e.g. pi+, pi-, pi(2)(1670)+, etc.
+    """
+    with pytest.raises(ParticleNotFound):
+        _ = Particle.from_name("pi")
+
+
+def test_from_nucleus_info():
     p = Particle.from_nucleus_info(1, 2)
     assert p.pdgid == 1000010020
     p = Particle.from_nucleus_info(92, 235)
     assert p.pdgid == 1000922350
     p = Particle.from_nucleus_info(1, 2, anti=True)
     assert p.pdgid == -1000010020
-    # No exited nuclei in database
-    try:
-        p = Particle.from_nucleus_info(1, 2, i=1)
-        assert p.pdgid == 1000010021
-    except ParticleNotFound:
-        pass
-    # No strange nuclei in database and strange PDGID not implemented
-    try:
-        p = Particle.from_nucleus_info(1, 2, l_strange=1)
-        assert p.pdgid == 1100010020
-    except ParticleNotFound and InvalidParticle:
-        pass
+
+
+def test_from_nucleus_info_ParticleNotFound():
+    with pytest.raises(ParticleNotFound):
+        _ = Particle.from_nucleus_info(z=999, a=999)
+
+        # No exited nuclei in database
+        _ = Particle.from_nucleus_info(1, 2, i=1)
+
+
+def test_from_nucleus_info_InvalidParticle():
+    with pytest.raises(InvalidParticle) as e:
+        _ = Particle.from_nucleus_info(z=2, a=1)
+
+    with pytest.raises(InvalidParticle) as e:
+        _ = Particle.from_nucleus_info(z=1, a=1000)
+
+    with pytest.raises(InvalidParticle) as e:
+        _ = Particle.from_nucleus_info(z=1000, a=1)
+
+    with pytest.raises(InvalidParticle) as e:
+        _ = Particle.from_nucleus_info(z=1, a=1, l_strange=999)
+
+    with pytest.raises(InvalidParticle) as e:
+        _ = Particle.from_nucleus_info(z=1, a=1, i=999)
+
+        # No strange nuclei in database and strange PDGID not implemented
+    with pytest.raises(InvalidParticle) as e:
+        _ = Particle.from_nucleus_info(1, 2, l_strange=1)
+    assert str(e.value) == "Input PDGID 1000110020 is invalid!"
 
 
 def test_sorting():
@@ -495,11 +527,15 @@ def test_is_unflavoured_meson(PDGIDs):
         PDGIDs.rho_1700_0,
         PDGIDs.a2_1320_minus,
         PDGIDs.omega_3_1670,
+        PDGIDs.f_4_2050,
         PDGIDs.f_4_2300,
         PDGIDs.jpsi,
         PDGIDs.psi_2S,
+        PDGIDs.psi_3770,
         PDGIDs.Upsilon_1S,
         PDGIDs.Upsilon_4S,
+        PDGIDs.Upsilon_3_2D,
+        PDGIDs.h_b_3P,
     )
     _non_unflavoured_mesons = [pid for pid in PDGIDs if pid not in _unflavoured_mesons]
     for pid in _unflavoured_mesons:
@@ -706,3 +742,8 @@ decfile_style_names = (
 @pytest.mark.parametrize("name,pid", decfile_style_names)
 def test_decfile_style_names(name, pid):
     assert Particle.from_evtgen_name(name).pdgid == pid
+
+
+@pytest.mark.parametrize("name,pid", decfile_style_names)
+def test_evtgen_name(name, pid):
+    assert Particle.from_evtgen_name(name).evtgen_name == name
